import { type MouseEventHandler, type FocusEventHandler, type MouseEvent, type KeyboardEvent, type ReactNode, type SyntheticEvent } from 'react';
import type { TNormalizedMenuVisibilities, TNormalizedPermissions, TNormalizedActionRights, TNormalizedDataFences } from '@commercetools-frontend/application-shell-connectors';
import { BackIcon } from '@commercetools-uikit/icons';
import type { TDataFence, TActionRight, TLocalizedField } from '../../types/generated/proxy';
type TProjectPermissions = {
    permissions: TNormalizedPermissions | null;
    actionRights: TNormalizedActionRights | null;
    dataFences: TNormalizedDataFences | null;
};
type IconProps = Parameters<typeof BackIcon>[0];
type IconSwitcherProps = {
    icon: string;
} & IconProps;
declare const IconSwitcher: {
    ({ icon, ...iconProps }: IconSwitcherProps): import("@emotion/react/jsx-runtime").JSX.Element;
    displayName: string;
};
type MenuExpanderProps = {
    isVisible: boolean;
    onClick: (e: MouseEvent<HTMLDivElement> | KeyboardEvent<HTMLDivElement>) => void;
    isMenuOpen: boolean;
};
declare const MenuExpander: {
    (props: MenuExpanderProps): import("@emotion/react/jsx-runtime").JSX.Element;
    displayName: string;
};
export type MenuGroupProps = {
    id: string;
    level: 1 | 2;
    isActive?: boolean;
    isExpanded?: boolean;
    hasSubmenu?: boolean;
    children?: ReactNode;
    submenuVerticalPosition?: number;
    isSubmenuAboveMenuItem?: boolean;
    handleKeyDown?: React.KeyboardEventHandler<HTMLUListElement>;
};
declare const MenuGroup: import("react").ForwardRefExoticComponent<MenuGroupProps & import("react").RefAttributes<HTMLUListElement>>;
type MenuItemProps = {
    hasSubmenu: boolean;
    isActive: boolean;
    isMainMenuRouteActive?: boolean;
    isMenuOpen: boolean;
    onClick: MouseEventHandler<HTMLElement>;
    onMouseEnter?: MouseEventHandler<HTMLElement> | FocusEventHandler<HTMLElement>;
    onMouseLeave?: MouseEventHandler<HTMLElement> | FocusEventHandler<HTMLElement>;
    children: ReactNode;
    identifier?: string;
    onKeyDown?: (e: React.KeyboardEvent<HTMLLIElement>) => void;
    onMouseMove?: MouseEventHandler<HTMLLIElement>;
};
declare const MenuItem: {
    (props: MenuItemProps): import("@emotion/react/jsx-runtime").JSX.Element;
    displayName: string;
};
export type MenuItemLinkProps = {
    linkTo?: string;
    exactMatch?: boolean;
    children: ReactNode;
    onClick?: (event: SyntheticEvent<HTMLAnchorElement>) => void;
    useFullRedirectsForLinks?: boolean;
    isSubmenuLink?: boolean;
    isSubmenuFocused?: boolean;
};
declare const MenuItemLink: {
    ({ exactMatch, ...props }: MenuItemLinkProps): import("@emotion/react/jsx-runtime").JSX.Element;
    displayName: string;
};
type RestrictedMenuItemProps = {
    featureToggle?: string;
    namesOfMenuVisibilities?: string[];
    projectPermissions: TProjectPermissions;
    menuVisibilities: TNormalizedMenuVisibilities | null;
    keyOfMenuItem: string;
    permissions: string[];
    actionRights?: TActionRight[];
    dataFences?: TDataFence[];
    children: ReactNode;
};
declare const RestrictedMenuItem: {
    ({ permissions, ...props }: RestrictedMenuItemProps): import("@emotion/react/jsx-runtime").JSX.Element | null;
    displayName: string;
};
type MenuLabelProps = {
    labelAllLocales: TLocalizedField[];
    defaultLabel?: string;
    applicationLocale: string;
};
declare const MenuLabel: (props: MenuLabelProps) => import("@emotion/react/jsx-runtime").JSX.Element;
type TNavBarLayoutProps = {
    children: ReactNode;
};
declare const NavBarLayout: import("react").ForwardRefExoticComponent<TNavBarLayoutProps & import("react").RefAttributes<HTMLElement>>;
type ItemContainerProps = {
    labelAllLocales: TLocalizedField[];
    defaultLabel?: string;
    applicationLocale: string;
    icon: string;
    isMenuOpen?: boolean;
};
declare const ItemContainer: {
    (props: ItemContainerProps): import("@emotion/react/jsx-runtime").JSX.Element;
    displayName: string;
};
export { RestrictedMenuItem, MenuItem, MenuItemLink, IconSwitcher, MenuGroup, MenuLabel, MenuExpander, NavBarLayout, ItemContainer, };
