import _mapInstanceProperty from '@babel/runtime-corejs3/core-js-stable/instance/map';
import _forEachInstanceProperty from '@babel/runtime-corejs3/core-js-stable/instance/for-each';

const DIMENSIONS = {
  header: '56px'
};
const NAVBAR = {
  expanderHeight: '50px',
  expanderSize: '40px',
  iconSize: '24px',
  iconSizeHover: '28px',
  itemSize: '48px',
  itemHeight: '56px',
  sublistIndentationWhenCollapsed: '72px',
  sublistIndentationWhenExpanded: '248px',
  sublistItemMinHeight: '50px',
  sublistWidth: '272px',
  leftNavigationTransition: 'all 150ms cubic-bezier(1, 0, 0.58, 1)',
  widthLeftNavigation: '80px',
  widthLeftNavigationWhenExpanded: '256px'
};
const WINDOW_SIZES = {
  STANDARD: 1024,
  WIDE: 1200
};
const CONTAINERS = {
  LOCALE_SWITCHER: 'locale-switcher-container',
  LEFT_OF_PROFILE: 'left-of-profile'
};
const SUSPENSION_REASONS = {
  TEMPORARY_MAINTENANCE: 'TemporaryMaintenance',
  PAYMENT: 'Payment',
  OTHER: 'Other'
};

// OIDC params
const OIDC_RESPONSE_TYPES = {
  ID_TOKEN: 'id_token'
};
const OIDC_CLAIMS = {
  OPEN_ID: 'openid',
  PROJECT_KEY: 'project_key',
  TEAM_ID: 'team_id',
  APPLICATION_ID: 'application_id',
  VIEW: 'view',
  MANAGE: 'manage'
};

const buildOidcScope = options => {
  var _context, _context2;
  const claims = [];

  // Set the projectKey
  if (options.projectKey) {
    claims.push(`${OIDC_CLAIMS.PROJECT_KEY}:${options.projectKey}`);
  }

  // Set the OAuth Scopes
  claims.push(..._mapInstanceProperty(_context = options.oAuthScopes?.view ?? []).call(_context, scope => `${OIDC_CLAIMS.VIEW}:${scope}`));
  claims.push(..._mapInstanceProperty(_context2 = options.oAuthScopes?.manage ?? []).call(_context2, scope => `${OIDC_CLAIMS.MANAGE}:${scope}`));
  // Set additional OAuth scopes
  if (options?.additionalOAuthScopes) {
    var _context3;
    _forEachInstanceProperty(_context3 = options.additionalOAuthScopes).call(_context3, additionalOAuthScope => {
      var _context4, _context5;
      claims.push(..._mapInstanceProperty(_context4 = additionalOAuthScope.view ?? []).call(_context4, viewOAuthScope => `view/${additionalOAuthScope.name}:${viewOAuthScope}`), ..._mapInstanceProperty(_context5 = additionalOAuthScope.manage ?? []).call(_context5, manageOAuthScope => `manage/${additionalOAuthScope.name}:${manageOAuthScope}`));
    });
  }

  // Set the teamId and applicationId
  if (options.teamId) {
    claims.push(`${OIDC_CLAIMS.TEAM_ID}:${options.teamId}`);
    if (options.applicationId) {
      claims.push(`${OIDC_CLAIMS.APPLICATION_ID}:${options.applicationId}`);
    }
  }
  return [
  // This is required as per OIDC spec.
  OIDC_CLAIMS.OPEN_ID,
  // Custom claims
  ...claims].join(' ');
};

export { CONTAINERS as C, DIMENSIONS as D, NAVBAR as N, OIDC_CLAIMS as O, SUSPENSION_REASONS as S, WINDOW_SIZES as W, OIDC_RESPONSE_TYPES as a, buildOidcScope as b };
